/*
 * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

// Local VOTCA includes
#include "votca/tools/propertyiomanipulator.h"

namespace votca {
namespace tools {

PropertyIOManipulator XML(PropertyIOManipulator::XML);
PropertyIOManipulator TXT(PropertyIOManipulator::TXT);
PropertyIOManipulator TEX(PropertyIOManipulator::TEX);
PropertyIOManipulator HLP(PropertyIOManipulator::HLP);

}  // namespace tools
}  // namespace votca
